@@ -310,6 +310,9 @@ class ImageTestCase(_TranslationTestCase):
 
 class SkipImageTestCase(_TranslationTestCase):
     relationship_dict = {
+        # These are only commented out because ``get_relationship_info`` strips
+        # them out, however since we have image_sizes I want to show that they
+        # are intentionally not added to the ``relationship_dict``
         #'rId0': 'media/image1.svg',
         #'rId1': 'media/image2.emf',
         #'rId2': 'media/image3.wmf',
@@ -707,3 +710,35 @@ class MangledIlvlTestCase(_TranslationTestCase):
 
         xml = DXB.xml(lis)
         return etree.fromstring(xml)
+
+
+class SeperateListsTestCase(_TranslationTestCase):
+    expected_output = '''
+    <html>
+        <ol data-list-type="decimal">
+            <li>AAA</li>
+        </ol>
+        <ol data-list-type="decimal">
+            <li>BBB</li>
+        </ol>
+        <ol data-list-type="decimal">
+            <li>CCC</li>
+        </ol>
+    </html>
+    '''
+
+    def get_xml(self):
+        li_text = [
+            ('AAA', 0, 2),
+            # Because AAA and CCC are part of the same list (same list id)
+            # and BBB is different, these need to be split into three
+            # lists (or lose everything from BBB and after.
+            ('BBB', 0, 1),
+            ('CCC', 0, 2),
+        ]
+        lis = ''
+        for text, ilvl, numId in li_text:
+            lis += DXB.li(text=text, ilvl=ilvl, numId=numId)
+
+        xml = DXB.xml(lis)
+        return etree.fromstring(xml)
